@@ -52,8 +52,8 @@ static inline _Complex double * _pCd(doublecomplex *z) {return (_Complex double*
 #endif
 #define pCf(z) (*_pCf(z))
 #define pCd(z) (*_pCd(z))
-typedef int logical;
-typedef short int shortlogical;
+typedef blasint logical;
+
 typedef char logical1;
 typedef char integer1;
 
@@ -260,7 +260,7 @@ static char junk[] = "\n@(#)LIBF77 VERSION 19990503\n";
 
 /* procedure parameter types for -A and -C++ */
 
-#define F2C_proc_par_types 1
+
 #ifdef __cplusplus
 typedef logical (*L_fp)(...);
 #else
@@ -718,7 +718,7 @@ f.f"> */
 /* > */
 /* > \endverbatim */
 /*  ===================================================================== */
-/* Subroutine */ int csyconvf_(char *uplo, char *way, integer *n, complex *a, 
+/* Subroutine */ void csyconvf_(char *uplo, char *way, integer *n, complex *a, 
 	integer *lda, complex *e, integer *ipiv, integer *info)
 {
     /* System generated locals */
@@ -727,7 +727,7 @@ f.f"> */
     /* Local variables */
     integer i__;
     extern logical lsame_(char *, char *);
-    extern /* Subroutine */ int cswap_(integer *, complex *, integer *, 
+    extern /* Subroutine */ void cswap_(integer *, complex *, integer *, 
 	    complex *, integer *);
     logical upper;
     integer ip;
@@ -768,13 +768,13 @@ f.f"> */
     if (*info != 0) {
 	i__1 = -(*info);
 	xerbla_("CSYCONVF", &i__1, (ftnlen)8);
-	return 0;
+	return;
     }
 
 /*     Quick return if possible */
 
     if (*n == 0) {
-	return 0;
+	return;
     }
 
     if (upper) {
@@ -1090,7 +1090,7 @@ f.f"> */
 /*        End A is LOWER */
 
     }
-    return 0;
+    return;
 
 /*     End of CSYCONVF */
 
